@@ -1,12 +1,13 @@
 import contextlib
-from typing import Iterator
+from typing import Iterator, Optional
 
 from . import client as _client
+from .client import RegisteredClient
 from .errors import ClientNotRegisteredError
 
 
 @contextlib.contextmanager
-def reset_client() -> Iterator[None]:
+def reset_client(new_client: Optional[RegisteredClient] = None) -> Iterator[None]:
     """Context manager to unregister the current client
 
     Once the context manager exits, the registered client is set back to it's original state
@@ -17,7 +18,7 @@ def reset_client() -> Iterator[None]:
         raise ClientNotRegisteredError()
 
     try:
-        _client._registered_client = None
+        _client._registered_client = new_client
         yield
     finally:
         _client._registered_client = client
